Wrap command - Run Parry wrapper in IPC mode
This command starts the wrapper that intercepts Claude Code file operations and validates them in real-time.
Structs
- Wrap
Command - Wrap command configuration
Wrap command - Run Parry wrapper in IPC mode
This command starts the wrapper that intercepts Claude Code file operations and validates them in real-time.