Claude Code integration hook
This command installs hooks that integrate Parry with Claude Code by intercepting file operations through the wrapper protocol.
Structs
- Hook
Command - Hook configuration
Claude Code integration hook
This command installs hooks that integrate Parry with Claude Code by intercepting file operations through the wrapper protocol.